@@ -60,9 +60,15 @@ void PartitionWidget::initUi()
     //分区页最上端的布局等
     topFrameSetting();
     m_topFrame->setFrameRounded(true);
+#if QT_VERSION_MAJOR > 5
+    DPalette palette = m_topFrame->palette();
+    palette.setBrush(DPalette::Base, palette.itemBackground());
+    m_topFrame->setPalette(palette);
+#else
     DPalette palette = DApplicationHelper::instance()->palette(m_topFrame);
     palette.setBrush(DPalette::Base, palette.itemBackground());
     DApplicationHelper::instance()->setPalette(m_topFrame, palette);
+#endif
     m_topFrame->setAutoFillBackground(true);
     //    m_topFrame->setStyleSheet("background:red");
     m_topFrame->setFixedSize(864, 110);
@@ -354,7 +360,11 @@ void PartitionWidget::partInfoShowing()
     font.setPixelSize(12);
 
     m_emptyLabel = new DLabel(m_partWidget);
+#if QT_VERSION_MAJOR > 5
+    m_emptyLabel->setFixedWidth(m_partFormateLabel->fontMetrics().boundingRect(tr("File system:")).width());
+#else
     m_emptyLabel->setFixedWidth(m_partFormateLabel->fontMetrics().width(tr("File system:")));
+#endif
     m_encryptionInfo = new DLabel(m_partWidget);
     m_encryptionInfo->setFont(font);
     m_encryptionInfo->setPalette(palette);
@@ -488,6 +498,15 @@ void PartitionWidget::setAddOrRemResult(const bool &isExceed)
 
 void PartitionWidget::setRegValidator()
 {
+#if QT_VERSION_MAJOR > 5
+    QRegularExpression reg("^[0-9]+(\\.[0-9]{1,4})?$");
+    QRegularExpressionValidator *va = new QRegularExpressionValidator(reg, this);
+    m_partSizeEdit->lineEdit()->setValidator(va);
+
+    QRegularExpression re("^[\u4E00-\u9FA5A-Za-z0-9_]+$");
+    QRegularExpressionValidator *va1 = new QRegularExpressionValidator(re, this);
+    m_partNameEdit->lineEdit()->setValidator(va1);
+#else
     QRegExp reg("^[0-9]+(\\.[0-9]{1,4})?$");
     QRegExpValidator *va = new QRegExpValidator(reg, this);
     m_partSizeEdit->lineEdit()->setValidator(va);
@@ -495,6 +514,7 @@ void PartitionWidget::setRegValidator()
     QRegExp re("^[\u4E00-\u9FA5A-Za-z0-9_]+$");
     QRegExpValidator *va1 = new QRegExpValidator(re, this);
     m_partNameEdit->lineEdit()->setValidator(va1);
+#endif
 }
 
 bool PartitionWidget::maxAmountPrimReached()
@@ -535,7 +555,11 @@ void PartitionWidget::onShowSelectPathInfo(const int &flag, const int &num, cons
         m_number = -1;
     } else if (m_flag == 2) {
         if (num < 0) {
+#if QT_VERSION_MAJOR > 5
+            DPalette palette = m_partNameLabel->palette();
+#else
             DPalette palette = DApplicationHelper::instance()->palette(m_partNameLabel);
+#endif
             palette.setBrush(DPalette::Text, palette.placeholderText());
             m_partNameLabel->setPalette(palette);
             m_partNameEdit->setEnabled(false);
@@ -575,7 +599,11 @@ void PartitionWidget::onShowTip(const int &hover, const int &num, const int &pos
 
 void PartitionWidget::setEnable(const int &flag, const bool &isExceed)
 {
+#if QT_VERSION_MAJOR > 5
+    DPalette palette = m_partNameLabel->palette();
+#else
     DPalette palette = DApplicationHelper::instance()->palette(m_partNameLabel);
+#endif
 
     if (isExceed) { //还有空闲空间剩余
         if (flag == 2) { //选中新建的分区
@@ -624,20 +652,34 @@ void PartitionWidget::setControlEnable(const bool &isTrue)
 void PartitionWidget::setLabelColor(const bool &isOk)
 {
     if (isOk) {
+#if QT_VERSION_MAJOR > 5
+        DPalette framePalette = m_botFrame->palette();
+#else
         DPalette framePalette = DApplicationHelper::instance()->palette(m_botFrame);
+#endif
         framePalette.setColor(DPalette::Text, QColor(palette().buttonText().color()));
         m_botFrame->setPalette(framePalette);
     } else {
+#if QT_VERSION_MAJOR > 5
+        DPalette palette = m_botFrame->palette();
+#else
         DPalette palette = DApplicationHelper::instance()->palette(m_botFrame);
+#endif
         palette.setBrush(DPalette::Text, palette.placeholderText());
         m_botFrame->setPalette(palette);
     }
 
+#if QT_VERSION_MAJOR > 5
+    DPalette palette1 = m_partInfoLabel->palette();
+    DPalette palatte2 = m_partDoLabel->palette();
+#else
     DPalette palette1 = DApplicationHelper::instance()->palette(m_partInfoLabel);
+    DPalette palatte2 = DApplicationHelper::instance()->palette(m_partDoLabel);
+#endif
+
     palette1.setColor(DPalette::Text, QColor(palette().buttonText().color()));
     m_partInfoLabel->setPalette(palette1);
 
-    DPalette palatte2 = DApplicationHelper::instance()->palette(m_partDoLabel);
     palatte2.setColor(DPalette::Text, QColor(palette().buttonText().color()));
     m_partDoLabel->setPalette(palatte2);
 }
@@ -894,9 +936,15 @@ void PartitionWidget::onAddPartition()
             warningBox.exec();
         }
 
+#if QT_VERSION_MAJOR > 5
+        DPalette palette = m_botFrame->palette();
+        palette.setColor(QPalette::ButtonText, color);
+        setPalette(palette);
+#else
         DPalette palette = DApplicationHelper::instance()->palette(m_botFrame);
         palette.setColor(QPalette::ButtonText, color);
         DApplicationHelper::instance()->setPalette(this, palette);
+#endif
 
         formate = formate.trimmed().split(" ").at(0);
     } else {
@@ -1112,7 +1160,11 @@ bool PartitionWidget::event(QEvent *event)
         qDebug() << event->type() << QApplication::font().pointSizeF() / 0.75;
         QFontMetrics fm(m_deviceNameLabel->font());
         m_deviceNameLabel->setFixedWidth(fm.boundingRect(tr("Disk:")).width() + 5);
+#if QT_VERSION_MAJOR > 5
+        m_emptyLabel->setFixedWidth(m_partFormateLabel->fontMetrics().boundingRect(tr("File system:")).width());
+#else
         m_emptyLabel->setFixedWidth(m_partFormateLabel->fontMetrics().width(tr("File system:")));
+#endif
         m_encryptionInfo->setFixedWidth(m_partFormateCombox->width());
         m_scrollArea->setFixedWidth(m_partFormateCombox->width());
         DWidget::event(event);
